@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-2.0 */
 /*
- * Copyright (C) 2015-2018 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
+ * Copyright (C) 2015-2019 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
  */
 
 #ifndef _WG_DEVICE_H
@@ -18,7 +18,7 @@
 #include <linux/net.h>
 #include <linux/ptr_ring.h>
 
-struct wireguard_device;
+struct wg_device;
 
 struct multicore_worker {
 	void *ptr;
@@ -36,7 +36,7 @@ struct crypt_queue {
 	};
 };
 
-struct wireguard_device {
+struct wg_device {
 	struct net_device *dev;
 	struct crypt_queue encrypt_queue, decrypt_queue;
 	struct sock __rcu *sock4, *sock6;
@@ -48,8 +48,8 @@ struct wireguard_device {
 	int incoming_handshake_cpu;
 	struct multicore_worker __percpu *incoming_handshakes_worker;
 	struct cookie_checker cookie_checker;
-	struct pubkey_hashtable peer_hashtable;
-	struct index_hashtable index_hashtable;
+	struct pubkey_hashtable *peer_hashtable;
+	struct index_hashtable *index_hashtable;
 	struct allowedips peer_allowedips;
 	struct mutex device_update_lock, socket_update_lock;
 	struct list_head device_list, peer_list;
@@ -59,7 +59,7 @@ struct wireguard_device {
 	bool have_creating_net_ref;
 };
 
-int device_init(void);
-void device_uninit(void);
+int wg_device_init(void);
+void wg_device_uninit(void);
 
 #endif /* _WG_DEVICE_H */
